@@ -3,7 +3,7 @@ use 5.014;
 use strict;
 use warnings;
 
-our $VERSION = "1.23";
+our $VERSION = "1.24";
 
 1;
 __END__
@@ -78,7 +78,7 @@ APISchema - Schema for API
     my $router = Router::Simple->new;
     $router->connect(...);
     my $generator = APISchema::Generator::Router::Simple->new;
-    $generator->generate_router($schema => $router);
+    $generator->inject_routes($schema => $router);
 
     # Documentation
     use APISchema::Generator::Markdown;
